@@ -263,7 +263,7 @@ def wham(bias,
             grad-=np.average(grad)
             return C,grad
         if minimize_opt is not None:
-            if not "method" in minimize_opt:
+            if "method" not in minimize_opt:
                 minimize_opt["method"]="L-BFGS-B"
             if "jac" in minimize_opt:
                 if not minimize_opt["jac"]:
@@ -300,6 +300,6 @@ def wham(bias,
     if verbose:
         sys.stderr.write("WHAM: end")
 
-    logW = cast(np.ndarray, logW) # to avoid mypy error
+    logW = cast(np.ndarray, logW)  # to avoid mypy error
 
     return WhamResult(logW=logW, logZ=np.log(Z)-shifts0, nit=nit, nfev=nfev, eps=eps)
